Command Completion
==================

The Interactive Python Shell provides automatic command completion that 
saves you typing and helps you discover what commands are available.

TODO - add detail here.